#!/usr/bin/perl -w

use strict;

#Maximum log size
use constant MAX_LOG_SIZE => 32768;

#Message delimiter - binary zero
use constant VZ_SEPARATOR => "\0";

#XML version
use constant XML_VERSION => "1.0";

#VZAgent protocol version
use constant AGENT_PROTOCOL_VERSION => "3.0.0";

#Response type constants
use constant RESPONSE_OK => 0;
use constant RESPONSE_ERROR => 1;
use constant RESPONSE_DATA => 2;

$/ = &VZ_SEPARATOR;

my $ADDR = "";
my $LOGIN = "";
my $COUNT = 1;

parse_options();
if ($ADDR eq "local")
{
	open_connect(\*RD, \*WR, "vzctl", "exec", "1", "/opt/vzagent/bin/vzlcon");
}
else
{
	open_connect(\*RD, \*WR, "nc", $ADDR, "4433");
}
setflush(\*WR);
setflush(\*STDOUT);
my $buf;
if (read_packet(\$buf) != RESPONSE_OK) {
	die "Can't establish connection\n";
}
print STDERR "Connection to $ADDR is established\n";

if ($LOGIN)
{
    login();
}

my $filename;
while ($filename = shift @ARGV)
{
	my $fh;
	print STDERR "Process $filename\n";
	if ($filename eq "-")
	{
		$fh = \*STDIN;
	}
	else
	{
		open($fh, "<", $filename)
		    or die "can't open $filename: $!";
	}
	print "ssss\n";
	while (1)
	{
		my $buf;
		#my $progress = 0;
		my $c = 0;
		while (($c < $COUNT) && ($buf = <$fh>))
		{
			chomp($buf);
			print STDERR ">";
			write_packet($buf);
			$c = $c + 1;
		}
		if (!$c)
		{
			last;
		}
		while ($c) {
			#$progress = 0;
			read_packet(\$buf);
			if ($buf =~ /progress>/)
			{
				print STDERR ".";
				#$progress = 1;
			}
			else
			{
				print STDOUT "$buf".$/;
				print STDERR "*";
				$c = $c - 1;
			}
		};
	}
	close($fh);
	print STDERR "\nFinish $filename\n";
}

sub login
{
	use MIME::Base64;
	my $pkt;
	my @fields;

	#print "---$LOGIN---";

	@fields = split(":", $LOGIN);
	# send login packet
	$pkt = "<packet version=\"". &AGENT_PROTOCOL_VERSION  ."\"><data><system><login><name>" .
	    encode_base64($fields[0],"") . "</name><password>" . 
	    encode_base64($fields[1],"") . "</password><realm>00000000-0000-0000-0000-000000000000</realm></login></system></data></packet>";

	my $buf;
	write_packet($pkt);
	#print $pkt . "\n";
	read_packet(\$buf);
	#print $buf . "\n";	
}

sub usage
{
	print STDERR "Usage: $0 [-l <user:passwd>] [-c <count>] [-o <out_file>] ADDR [pkt|-] ...\n";
	exit(1);
}

sub parse_options
{
	use Getopt::Std;
	my ($optstring, %opt);
	$optstring = "l:c:";
	getopts($optstring, \%opt) or usage( );
	$LOGIN=$opt{l};
	if ($opt{c})
	{
		$COUNT = $opt{c};
	}
	$ADDR = shift @ARGV;
	$ADDR || usage();
}

sub write_packet
{
	my $buf = shift;
	print WR $buf.$/;
}

sub read_packet
{
	my $XMLContainer = shift;
	my $buf = "";
	$buf = <RD> || return RESPONSE_ERROR;
	#$buf =~ s/^Permission denied.*?\n//mg;
	#exit(1) if "$buf" eq "";
	chomp($buf);
	$$XMLContainer = $buf;
	return RESPONSE_OK;
}

sub open_connect
{
	my ($rd, $wr) = (shift, shift);
	my $rd_ssh = undef;
	my $wr_ssh = undef;

	exit(1)
	    unless (pipe ($rd, WR_SSH) && pipe (RD_SSH, $wr));
	    $rd_ssh = \*RD_SSH;
	    $wr_ssh = \*WR_SSH;

	my $pid = fork();
	exit(1)
	    unless defined($pid);

	if (!$pid)
	{
		# Ssh channel
		close($$rd); close($$wr);

		close(STDOUT); open(STDOUT, ">&".fileno($wr_ssh));
		close(STDIN); open(STDIN, "<&".fileno($rd_ssh));
		close(STDERR); open(STDERR, ">&".fileno($wr_ssh));

		exec(@_);
		exit(127);
	}

	# Main program
	close($wr_ssh);
	close($rd_ssh);
	return $pid;
}

sub setflush
{
	select($_[0]);
	$| = 1;
	select(STDOUT);
}
