#!/bin/bash
#
# Tool for collect report of VZAgent related info & statistic & logs.
#
# ToDo:
#	* process mem & cpu usage report
#	* DB size, table counts report  
#

# VZL defines
. /var/vzagent/etc/vzl_defines

# VZL functions.
. /var/vzagent/etc/vzl_functions


SERVICE_VEID=1
LDAPSEARCH=ldapsearch

function usage()
{
    echo "Usage: vzagentCollectReport.sh <dir>"
}

# Get VE root
function getVERoot()
{
	VEID=$1
	. /etc/vz/conf/$VEID.conf	
	echo $VE_ROOT
}

function copyLogsConfigs()
{
    local targetDir=$1
    local SVE_ROOT=`getVERoot ${SERVICE_VEID}`
    cp -afr ${VZLCORE_LOG_DIR} $targetDir
    cp -af ${HOME}/vzinstall.log $targetDir
    cp -af /var/log/vzsveinstall.log $targetDir
    cp -af /var/log/vzsveupgrade.log $targetDir
    cp -af /var/log/vzup2date.log $targetDir
    cp -af ${HOME}/vzinstaller-vt.log $targetDir
    cp -af ${VZLCORE_ETC_DIR}/vzagent.conf $targetDir
    cp -af ${VZLCORE_ETC_DIR}/schedules.conf $targetDir
    cp -af ${SVE_ROOT}/etc/httpd/conf.d/vzlsoap.conf $targetDir
    
}

function dumpVZAgentInfo()
{
    local targetDir=$1
    ${VZLCORE_BIN_DIR}/vzagentInfoReport.sh > $targetDir/vzagentInfo.txt
}

function dumpLDAPDatabase()
{
    local targetDir=$1   
    local vzlLdapUserPassword=`${VZLCORE_BIN_DIR}/base64 -d < ${VZLCORE_PSTORAGE_DIR}/${VZL_LDAP_USER} | sed -e "s#vzagent##"`
    vzlLdapUserPassword=`echo -ne $vzlLdapUserPassword`  
    local eid=`vzctl exec ${SERVICE_VEID} cat ${VZLCORE_ETC_DIR}/eid`
    vzctl exec ${SERVICE_VEID} ${LDAPSEARCH} -c -x -w "${vzlLdapUserPassword}" -D "cn=${VZL_LDAP_USER},dc=VZL" -b CN=Roles,OU=$eid,DC=VZL > $targetDir/Roles.ldif
    vzctl exec ${SERVICE_VEID} ${LDAPSEARCH} -c -x -w "${vzlLdapUserPassword}" -D "cn=${VZL_LDAP_USER},dc=VZL" -b OU=VZLInfrastructure,OU=$eid,DC=VZL >$targetDir/Infrastructure.ldif
    vzctl exec ${SERVICE_VEID} ${LDAPSEARCH} -c -x -w "${vzlLdapUserPassword}" -D "cn=${VZL_LDAP_USER},dc=VZL" -b OU=VZLOrganization,OU=$eid,DC=VZL >$targetDir/Organization.ldif
}

function dumpSQLDatabase()
{
    local targetDir=$1
    local eid=`vzctl exec ${SERVICE_VEID} cat ${VZLCORE_ETC_DIR}/eid`
    vzctl exec ${SERVICE_VEID} mysql > $targetDir/SQL.dmp << MSEOF

use VZLLogDB$eid;

select count(*) from op_log;
select count(*) from op_log_data;
select count(*) from op_log_env;
select count(*) from op_log_task;
select count(*) from env_log;
select count(*) from events_log;
select count(*) from events_log_env;
select count(*) from events_log_resource;
select count(*) from events_log_status;

use VZLResLog$eid;

select count(*) from log_data;
select count(*) from log_def;
select * from log_data order by end_time desc limit 1;
select * from log_data order by start_time limit 1;
select distinct eid from log_def;

MSEOF
}

if [ $# == 1 ]; then

	if [ -d $1 ]; then
		# Copy logs & configs
		copyLogsConfigs $1
		# Dump VZAgent Info
		dumpVZAgentInfo $1
		# Dump LDAP database
		dumpLDAPDatabase $1
		# Dump SQL database
		dumpSQLDatabase $1
	else
		usage; exit -1
	fi

else
    usage; exit -1
fi

