/*---------------------------------------------------------------------------*/
/*	LogDBOperator                                                        */
/*---------------------------------------------------------------------------*/

create database if not exists `VZLLogDB00000000-0000-0000-0000-000000000002`;
use `VZLLogDB00000000-0000-0000-0000-000000000002`;

drop table if exists op_log;
create table if not exists op_log (
        op_id           int auto_increment,
        op              char(32) not null,
        id              char(255) not null,
        parent_id       char(255) not null DEFAULT "",
        time            int not null,
        status          int default 0,
        PRIMARY KEY(op_id),
        KEY(op),
        KEY(id),
        KEY(parent_id),
        KEY(time),
        KEY(status)
) type = Innobase;

drop table if exists op_log_data;
create table if not exists op_log_data (
        data_id         int auto_increment,
        op_id           int NOT NULL,
        cur_percent     int default 0,
        time            int not null,
        status          int not null,
        message         text,
        KEY(op_id),
        KEY(data_id),
	FOREIGN KEY(op_id) REFERENCES op_log(op_id) ON DELETE RESTRICT ON UPDATE CASCADE
) type = Innobase;


drop table if exists events_log;
create table if not exists events_log (
        recordNumber    int auto_increment,
        id            char(48) NOT NULL,
        count           int not null,
        time            int not null,
        source          char(255) NOT NULL,
	category        char(255) NOT NULL,
	sid             char(255) not NULL,
        info            text,
        data            text,
        PRIMARY KEY(recordNumber),
        KEY(id),
        KEY(count),
        KEY(time),
        KEY(source),
        KEY(category),
        KEY(sid)
) type = Innobase;

drop table if exists env_log;
create table if not exists env_log (
	env_log_id	int unsigned not null auto_increment,
	env_id		char(36) not null default '00000000-0000-0000-0000-000000000000',
	env_title	varchar(255) not null default '',
	env_type	varchar(16) not null default '',
	PRIMARY KEY(env_log_id),
	KEY(env_id),
	KEY(env_id, env_title)
) type = Innobase;

drop table if exists op_log_task;
create table if not exists op_log_task (
	op_id		int not null,
	task_id		varchar(255) not null default '',
	KEY(op_id),
	KEY(task_id),
	UNIQUE(op_id, task_id),
	FOREIGN KEY(op_id)	REFERENCES op_log(op_id) ON DELETE CASCADE
) type = Innobase;

drop table if exists op_log_env;
create table if not exists op_log_env (
	op_id		int not null,
	env_log_id	int unsigned not null default 0,
	env_role	char(1) not null default 'O',	-- possible values: O - operand, S - source
	KEY(op_id, env_role),
	KEY(env_log_id),
	UNIQUE(op_id, env_log_id, env_role),
	FOREIGN KEY(op_id) REFERENCES op_log(op_id) ON DELETE CASCADE,
	FOREIGN KEY(env_log_id)	REFERENCES env_log(env_log_id) ON DELETE CASCADE
) type = Innobase;

drop table if exists events_log_env;
create table if not exists events_log_env (
	recordNumber	int not null,
	env_log_id	int unsigned not null default 0,
	env_role	char(1) not null default 'O',	-- possible values: O - operand, S - source
	KEY(recordNumber, env_role),
	KEY(env_log_id),
	UNIQUE(recordNumber, env_log_id, env_role),
	FOREIGN KEY(recordNumber) REFERENCES events_log(recordNumber) ON DELETE CASCADE,
	FOREIGN KEY(env_log_id)	REFERENCES env_log(env_log_id) ON DELETE CASCADE
) type = Innobase;

drop table if exists events_log_status;
create table if not exists events_log_status (
	recordNumber	int not null,
	old_status	tinyint unsigned not null default 0,
	old_transition	tinyint unsigned not null default 0,
	new_status	tinyint unsigned not null default 0,
	new_transition	tinyint unsigned not null default 0,
	KEY(recordNumber),
	FOREIGN KEY(recordNumber) REFERENCES events_log(recordNumber) ON DELETE CASCADE
) type = Innobase;

drop table if exists events_log_resource;
create table if not exists events_log_resource (
	recordNumber	int not null,
	resource_name	varchar(255) not null default '',
	alert_type	varchar(255) not null default '',
	KEY(recordNumber),
	FOREIGN KEY(recordNumber) REFERENCES events_log(recordNumber) ON DELETE CASCADE
) type = Innobase;

